@@ -15,7 +15,8 @@ from pathlib import Path
 from pprint import pprint
 from bs4 import BeautifulSoup
 from email.message import EmailMessage
-from Adlib.api import EnumBanco, EnumProcesso
+from Adlib.enums import EnumStatus
+from Adlib.api import EnumBanco, EnumProcesso, putStatusRobo
 from Adlib.utils import loginChatIdMapping
 from selenium import webdriver
 from selenium.webdriver import Chrome
@@ -569,7 +570,7 @@ def rightClick(driver: Chrome, xpath: str):
     actions.context_click(element).perform()
     
 
-def moveToElement(driver: Chrome, xpath: str):
+def moveToElement(driver: Chrome, xpath: str, click: bool = False):
     """
     Moves the mouse to the position where the element is located.
 
@@ -579,7 +580,10 @@ def moveToElement(driver: Chrome, xpath: str):
     """
     element = esperarElemento(driver, xpath)
     actions = ActionChains(driver)
-    actions.move_to_element(element).perform()
+    if click:
+        actions.move_to_element(element).click().perform()
+    else:
+        actions.move_to_element(element).perform()
 
 
 def coletarPinBanrisul(email: str, pasta: str):
@@ -600,14 +604,16 @@ def dataEscolha(days: int, formato: str = '%d/%m/%Y') -> str:
     return (datetime.datetime.today() - datetime.timedelta(days=days)).strftime(formato)
 
 
-def horaFinalizacao(hora=18, minuto=0):
-    """
-    Retorna True se já passou do horário especificado. 
-    Default: 18:00
-    """
+def horaFinalizacao(driver, enumProcesso, enumBanco, hora=18, minuto=0):
     agora = datetime.datetime.now()
-    horario_limite = agora.replace(hour=hora, minute=minuto)
-    return agora >= horario_limite
+    horario_limite = agora.replace(hour=hora, minute=minuto, second=0, microsecond=0)
+
+    if agora >= horario_limite:
+        putStatusRobo(EnumStatus.DESLIGADO, enumProcesso, enumBanco)
+        driver.quit()
+        return True  # sinaliza que deve parar
+
+    return False  # ainda não é hora
 
 
 def coletarDadosEmail(
