@@ -57,7 +57,7 @@ chatIdEsteiraLogin = "-1002257326271"
 chatIdIntegracaoLogin = "-1002556560733"
 chatIdUsuariosLogin = "-4095757991"
 chatIdConfirmacaoLogin = "-4643090903"
-chatIdAtendimento = "-910947972"
+chatIdConsulta = "-910947972"
 chatIdConfirmacao = "-1002420514126"
 chatIdCriacao = "-1001716522279"
 chatIdReset = "-1002798198497"
@@ -88,8 +88,8 @@ chatIdMapping = {
     EnumProcesso.CONFIRMACAO_CREDITO: chatIdConfirmacao,
     EnumProcesso.ANALISE_DOCUMENTOS: chatIdAnalise,
     EnumProcesso.INTEGRACAO: chatIdIntegracao,
-    EnumProcesso.BLIP_LINK: chatIdAtendimento,
-    EnumProcesso.BLIP_CONSULTA: chatIdAtendimento,
+    EnumProcesso.BLIP_LINK: chatIdConsulta,
+    EnumProcesso.BLIP_CONSULTA: chatIdConsulta,
     EnumProcesso.PAG_DEV: chatIdPagDev,
     EnumProcesso.IMPORTACAO: chatIdImportacao,
     (EnumProcesso.IMPORTACAO, EnumBanco.PAN): chatIdAutenticacaoPan,
